execute

Function execute 

pub fn execute(
    deps: DepsMut<'_>,
    env: Env,
    info: MessageInfo,
    msg: ExecuteMsg,
) -> Result<Response, ContractError>
Exposes all the execute functions available in the contract.

Execute messages

  • ExecuteMsg::SubmitProposal { title, description, link, messages, ibc_channel } Submits a new proposal.

  • ExecuteMsg::CheckMessages { messages } Checks if the messages are correct. Executes arbitrary messages on behalf of the Assembly contract. Always appends failing message to the end of the list.

  • ExecuteMsg::CheckMessagesPassed {} Closing message for the CheckMessages endpoint.

  • ExecuteMsg::CastVote { proposal_id, vote } Cast a vote on a specific proposal.

  • ExecuteMsg::CastVoteOutpost { voter, voting_power, proposal_id, vote } Applies a vote on a specific proposal from outpost. Only emissions controller is allowed to call this endpoint.

  • ExecuteMsg::EndProposal { proposal_id } Sets the status of an expired/finalized proposal.

  • ExecuteMsg::ExecuteProposal { proposal_id } Executes a successful proposal.

  • ExecuteMsg::UpdateConfig(config) Updates the contract configuration.

  • ExecuteMsg::IBCProposalCompleted { proposal_id, status } Updates proposal status InProgress -> Executed or Failed. This endpoint processes callbacks from the ibc controller.