submit_proposal

Function submit_proposal 

pub fn submit_proposal(
    deps: DepsMut<'_>,
    env: Env,
    info: MessageInfo,
    title: String,
    description: String,
    link: Option<String>,
    messages: Vec<CosmosMsg>,
    ibc_channel: Option<String>,
) -> Result<Response, ContractError>
Submit a brand new proposal and lock some xASTRO as an anti-spam mechanism.

  • sender proposal submitter.

  • deposit_amount amount of xASTRO to deposit in order to submit the proposal.

  • title proposal title.

  • description proposal description.

  • link proposal link.

  • messages executable messages (actions to perform if the proposal passes).