pub struct OldProposal {Show 19 fields
pub proposal_id: Uint64,
pub submitter: Addr,
pub status: ProposalStatus,
pub for_power: Uint128,
pub outpost_for_power: Uint128,
pub against_power: Uint128,
pub outpost_against_power: Uint128,
pub start_block: u64,
pub start_time: u64,
pub end_block: u64,
pub delayed_end_block: u64,
pub expiration_block: u64,
pub title: String,
pub description: String,
pub link: Option<String>,
pub messages: Vec<CosmosMsg>,
pub deposit_amount: Uint128,
pub ibc_channel: Option<String>,
pub total_voting_power: Uint128,
}Fields
proposal_id: Uint64submitter: Addrstatus: ProposalStatusfor_power: Uint128outpost_for_power: Uint128against_power: Uint128outpost_against_power: Uint128start_block: u64start_time: u64end_block: u64delayed_end_block: u64expiration_block: u64title: Stringdescription: Stringlink: Option<String>messages: Vec<CosmosMsg>deposit_amount: Uint128ibc_channel: Option<String>total_voting_power: Uint128Trait Implementations
Sourceimpl Clone for OldProposal
impl Clone for OldProposal
Sourcefn clone(&self) -> OldProposal
fn clone(&self) -> OldProposal
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OldProposal
impl Debug for OldProposal
Sourceimpl<'de> Deserialize<'de> for OldProposal
impl<'de> Deserialize<'de> for OldProposal
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OldProposal
impl JsonSchema for OldProposal
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OldProposal
impl PartialEq for OldProposal
Sourceimpl Serialize for OldProposal
impl Serialize for OldProposal
impl StructuralPartialEq for OldProposal